@@ -605,7 +605,8 @@ netstatus_icon_size_allocate (GtkWidget     *widget,
   NetstatusIcon *icon = (NetstatusIcon *) widget;
   GtkAllocation  child_allocation;
   GObjectClass  *klass;
-  int            size;
+  gint           size;
+  guint          border_width;
 
   if (icon->priv->orientation == GTK_ORIENTATION_HORIZONTAL)
     size = allocation->height;
@@ -619,43 +620,47 @@ netstatus_icon_size_allocate (GtkWidget     *widget,
       netstatus_icon_scale_icons (icon, size);
     }
 
-  if (GTK_WIDGET_REALIZED (widget))
+  if (gtk_widget_get_realized (widget))
     {
-      gdk_window_move_resize (widget->window,
-                              allocation->x + GTK_CONTAINER (widget)->border_width,
-                              allocation->y + GTK_CONTAINER (widget)->border_width,
-                              MAX (allocation->width - GTK_CONTAINER (widget)->border_width * 2, 0),
-			      MAX (allocation->height - GTK_CONTAINER (widget)->border_width * 2, 0));
+      border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
+      gdk_window_move_resize (gtk_widget_get_window (widget),
+                              allocation->x + border_width,
+                              allocation->y + border_width,
+                              MAX (allocation->width - border_width * 2, 0),
+                              MAX (allocation->height - border_width  * 2, 0));
     }
 
   klass = get_box_class (icon->priv->orientation);
 
   child_allocation.x = 0;
   child_allocation.y = 0;
-  child_allocation.width  = MAX (allocation->width  - GTK_CONTAINER (widget)->border_width * 2, 0);
-  child_allocation.height = MAX (allocation->height - GTK_CONTAINER (widget)->border_width * 2, 0);
+  child_allocation.width  = MAX (allocation->width  - border_width * 2, 0);
+  child_allocation.height = MAX (allocation->height - border_width * 2, 0);
 
   if (GTK_WIDGET_CLASS (klass)->size_allocate)
     GTK_WIDGET_CLASS (klass)->size_allocate (widget, &child_allocation);
 
-  widget->allocation = *allocation;
+  gtk_widget_set_allocation (widget, allocation);
 }
 
 static void
 netstatus_icon_realize (GtkWidget *widget)
 {
+  GdkWindow     *window;
   GdkWindowAttr attributes;
+  GtkAllocation allocation;
   int           attributes_mask;
   int           border_width;
 
-  GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
+  gtk_widget_set_realized (widget, TRUE);
   
-  border_width = GTK_CONTAINER (widget)->border_width;
+  border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
 
-  attributes.x = widget->allocation.x + border_width;
-  attributes.y = widget->allocation.y + border_width;
-  attributes.width = widget->allocation.width - 2 * border_width;
-  attributes.height = widget->allocation.height - 2 * border_width;
+  gtk_widget_get_allocation (widget, &allocation);
+  attributes.x = allocation.x + border_width;
+  attributes.y = allocation.y + border_width;
+  attributes.width = allocation.width - 2 * border_width;
+  attributes.height = allocation.height - 2 * border_width;
   attributes.window_type = GDK_WINDOW_CHILD;
   attributes.wclass = GDK_INPUT_OUTPUT;
   attributes.visual = gtk_widget_get_visual (widget);
@@ -670,11 +675,16 @@ netstatus_icon_realize (GtkWidget *widget)
 
   attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
 
-  widget->window = gdk_window_new (gtk_widget_get_parent_window (widget), &attributes, attributes_mask);
-  gdk_window_set_user_data (widget->window, widget);
+  window = gdk_window_new (gtk_widget_get_parent_window (widget),
+                           &attributes,
+                           attributes_mask);
+  gtk_widget_set_window (widget, window);
+  gdk_window_set_user_data (window, widget);
 
-  widget->style = gtk_style_attach (widget->style, widget->window);
-  gtk_style_set_background (widget->style, widget->window, GTK_STATE_NORMAL);
+  gtk_widget_style_attach (widget);
+  gtk_style_set_background (gtk_widget_get_style (widget),
+                            window,
+                            GTK_STATE_NORMAL);
 }
 
 static gboolean
@@ -850,7 +860,7 @@ netstatus_icon_instance_init (NetstatusIcon      *icon,
 {
   icon->priv = g_new0 (NetstatusIconPrivate, 1);
 
-  GTK_WIDGET_UNSET_FLAGS (icon, GTK_NO_WINDOW);
+  gtk_widget_set_has_window (GTK_WIDGET (icon), TRUE);
 
   icon->priv->iface            = NULL;
   icon->priv->state            = NETSTATUS_STATE_DISCONNECTED;
